unit mediareg;

interface

uses Classes, Menus, dialogs, DsgnIntf;

procedure Register;

implementation {===========================================================}

uses MediaLib, SelCol, Graphics, sysUtils, WavCtrl, Forms, ColCombo,
     Regions, FrmRgn, FrmGRgn, FrmLL, MediaBtn, frmBlur;

type

  TColorProperty = class(TPropertyEditor)
  private
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
    procedure SetValue(const Value: string); override;
  end;

procedure TColorProperty.Edit;
begin
  SetOrdValue(SelColor(GetOrdValue));
end;

function TColorProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog,paMultiSelect];
end;

function TColorProperty.GetValue: string;
begin
  Result := IntToStr(GetOrdValue);
end;

procedure TColorProperty.SetValue(const Value: string);
begin
  SetOrdValue(StrToInt(Value));
end;

{ ==========================================================}

type

  TmlRegionGraphicProperty = class(TPropertyEditor)
  private
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
    procedure SetValue(const Value: string); override;
  end;

procedure TmlRegionGraphicProperty.Edit;
var
  Comp: TmlRegionGraphicControl;
begin
  try
    Comp := TmlRegionGraphicControl(GetComponent(0));
    FrmGRgn.execute(comp);
  finally
  end;
end;

function TmlRegionGraphicProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function TmlRegionGraphicProperty.GetValue: string;
begin
  Result := '(Mask)';
end;

procedure TmlRegionGraphicProperty.SetValue(const Value: string);
begin
  if Value = '' then SetOrdValue(0);
end;

{ ==========================================================}

type

  TSoundProperty = class(TPropertyEditor)
  public
    procedure Edit; override;
    function GetAttributes: TPropertyAttributes; override;
    function GetValue: string; override;
    procedure SetValue(const Value: string); override;
  end;

{ TSoundProperty ====================================== }

procedure TSoundProperty.Edit;
var
  Comp: TmlWavePlayer;
  OpenDialog: TOpenDialog;
begin
  try
    Comp := TmlWavePlayer(GetComponent(0));
    OpenDialog := TOpenDialog.Create(Application);
    OpenDialog.FileName := '*.wav';
    OpenDialog.Filter := 'WAV Files|*.wav|All files|*.*';
    If OpenDialog.Execute then
    begin
      Comp.Wave.LoadFromFile(OpenDialog.FileName);
      Comp.Wave.Modified := true;
    end;
    OpenDialog.Free;
  finally
  end;
end;

function TSoundProperty.GetAttributes: TPropertyAttributes;
begin
  Result := [paDialog];
end;

function TSoundProperty.GetValue: string;
begin
  Result := '(WAV Sound)';
end;

procedure TSoundProperty.SetValue(const Value: string);
begin
  if Value = '' then SetOrdValue(0);
end;

{ ==========================================================}

type

{ TmlRegionFormEditor }

  TmlRegionFormEditor = class(TComponentEditor)
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

{ TmlRegionFormEditor }

procedure TmlRegionFormEditor.ExecuteVerb(Index: Integer);
var
  Ctrl: TmlRegionForm;
begin
  Ctrl := Component as TmlRegionForm;
  if Index = 0 then FrmRgn.Execute(Ctrl);
end;

function TmlRegionFormEditor.GetVerb(Index: Integer): string;
begin
  case Index of
    0: Result := 'Region Edit';
    else Result := '';
  end;
end;

function TmlRegionFormEditor.GetVerbCount: Integer;
begin
  Result := 1;
end;

{ ==========================================================}

type

{ TmlLLEditor }

  TmlLLEditor = class(TComponentEditor)
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

{ TmlLLEditor }

procedure TmlLLEditor.ExecuteVerb(Index: Integer);
var
  Ctrl: TmlLightLabelButton;
begin
  Ctrl := Component as TmlLightLabelButton;
  if Index = 0 then frmLL.Execute(Ctrl);
end;

function TmlLLEditor.GetVerb(Index: Integer): string;
begin
  case Index of
    0: Result := 'Light Label Button Edit';
    else Result := '';
  end;
end;

function TmlLLEditor.GetVerbCount: Integer;
begin
  Result := 1;
end;

{ ==========================================================}

type

{ TmlBlurEditor }

  TmlBlurEditor = class(TComponentEditor)
    procedure ExecuteVerb(Index: Integer); override;
    function GetVerb(Index: Integer): string; override;
    function GetVerbCount: Integer; override;
  end;

{ TmlBlurEditor }

procedure TmlBlurEditor.ExecuteVerb(Index: Integer);
var
  Ctrl: TmlBlurButton;
begin
  Ctrl := Component as TmlBlurButton;
  if Index = 0 then frmBlur.Execute(Ctrl);
end;

function TmlBlurEditor.GetVerb(Index: Integer): string;
begin
  case Index of
    0: Result := 'Blur Button Edit...';
    else Result := '';
  end;
end;

function TmlBlurEditor.GetVerbCount: Integer;
begin
  Result := 1;
end;

{ Registration }

procedure Register;
begin
  RegisterComponents('Additional', [TmlColorComboBox]);

  RegisterComponents('Media Lib',
  [
    TmlBitmap,
    TmlWavePlayer,
    TmlMediaPanel,
    TmlMediaBevel,

    TmlMediaButton,
    TmlBitmapButton,
    TmlLightLabelButton,
    TmlBlurButton,

    TmlShadowPanel,
    TmlMorphing,
    TmlTracker,

    TmlRegionForm,
    TmlRegionGraphicControl,
    TmlRegionSpeedButton
  ]);

  RegisterClass(TmlWave);

  RegisterPropertyEditor(TypeInfo(TColor),
    TmlMediaPanel, '', TColorProperty);
  RegisterPropertyEditor(TypeInfo(TColor),
    TmlMediaBevel, '', TColorProperty);
  RegisterPropertyEditor(TypeInfo(TColor),
    TmlMediaButton, '', TColorProperty);

  RegisterPropertyEditor(TypeInfo(TBitmap),
    TmlRegionGraphicControl, 'Mask', TmlRegionGraphicProperty);

  RegisterComponentEditor(TmlRegionForm, TmlRegionFormEditor);
  RegisterComponentEditor(TmlLightLabelButton, TmlLLEditor);
  RegisterComponentEditor(TmlBlurButton, TmlBlurEditor);

  RegisterPropertyEditor(TypeInfo(TmlWave), nil,
    '', TSoundProperty);
end;

end.
